==> gbackpacks-1.21.1-beta%2B3-sources.jar: com/macuguita/backpacks/client/model/GBModelLoadingPlugin.java <==
/*
 * Copyright (c) 2025 macuguita
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 * OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.macuguita.backpacks.client.model;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.client.model.loading.v1.ModelLoadingPlugin;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3300;

@Environment(EnvType.CLIENT)
public class GBModelLoadingPlugin implements ModelLoadingPlugin {

	@Override
	public void onInitializeModelLoader(Context context) {
		class_3300 manager = class_310.method_1551().method_1478();

		var resources = manager.method_14488("models/backpacks", path -> path.method_12832().endsWith(".json"));

		resources.forEach((key, resource) -> {
			String relPath = key.method_12832()
					.substring("models/".length(), key.method_12832().length() - ".json".length());
			class_2960 id = class_2960.method_60655(key.method_12836(), relPath);

			context.addModels(id);
		});
	}
}

==> gbackpacks-1.21.10-beta%2B3-sources.jar: com/macuguita/backpacks/client/model/GBModelLoadingPlugin.java <==
/*
 * Copyright (c) 2025 macuguita
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 * OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.macuguita.backpacks.client.model;

import java.util.HashMap;
import java.util.Map;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.client.model.loading.v1.ExtraModelKey;
import net.fabricmc.fabric.api.client.model.loading.v1.ModelLoadingPlugin;
import net.fabricmc.fabric.api.client.model.loading.v1.SimpleUnbakedExtraModel;
import net.minecraft.class_1087;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3300;

@Environment(EnvType.CLIENT)
public class GBModelLoadingPlugin implements ModelLoadingPlugin {

	private static final Map<class_2960, ExtraModelKey<class_1087>> blockStateModels = new HashMap<>();

	@Override
	public void initialize(Context context) {
		class_3300 resourceManager = class_310.method_1551().method_1478();

		var resources = resourceManager.method_14488("models/backpacks", path -> path.method_12832().endsWith(".json"));

		resources.forEach((key, resource) -> {
			String relPath = key.method_12832()
					.substring("models/".length(), key.method_12832().length() - ".json".length());
			class_2960 id = class_2960.method_60655(key.method_12836(), relPath);

			ExtraModelKey<class_1087> modelKey = ExtraModelKey.create(id::toString);

			context.addModel(modelKey, SimpleUnbakedExtraModel.blockStateModel(id));
			blockStateModels.put(id, modelKey);
		});
	}

	public static ExtraModelKey<class_1087> getModelKey(class_2960 id) {
		return blockStateModels.get(id);
	}

	public static class_1087 getBlockstateModel(class_2960 id) {
		return class_310.method_1551().method_1554().getModel(getModelKey(id));
	}
}
